@@ -12,8 +12,8 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "./enums.h"
-#include "./applet.h"
+#include "enums.h"
+#include "applet.h"
 
 extern "C"
 {
